"""This module checks avaliable displays depending on the display server"""

import os

def detect_display_server():
    if os.environ.get('WAYLAND_DISPLAY'):
        return "Wayland"
    else:
        return "Xorg"

def get_wayland_displays():
    displays = []
    wayland_socket = os.environ.get('WAYLAND_DISPLAY')
    if wayland_socket:
        displays.append(f"wayland-{wayland_socket}")
    return displays

def get_xorg_displays():
    displays = []
    xorg_display = os.environ.get('DISPLAY')
    if xorg_display:
        displays.append(f"xorg-{xorg_display}")
    return displays

def main(display_server):
    available_displays = []

    if display_server.lower() == "wayland":
        displays = get_wayland_displays()
    else:
        displays = get_xorg_displays()
    available_displays.extend(displays)

    if not available_displays:
        print("No displays found.")
    else:
        print("Available displays:")
        for display in available_displays:
            print(display)

if __name__ == "__main__":
    display_server = detect_display_server()
    print(f"The system is running under: {display_server}")
    main(display_server)



from waypaper.app import App
from waypaper.changer import change_wallpaper
from waypaper.config import cf
from waypaper.arguments import args


__version__ = "1.8"


def run():
    """Read user arguments and either run GUI app or just reset the wallpaper"""

    # Set the wallpaper and quit:
    if args.restore:
        if cf.wallpaper is not None:
            change_wallpaper(cf.wallpaper, cf.fill_option, cf.color, cf.backend)
        exit()

    # Print the version and quit:
    if args.version:
        print(f"waypaper v.{__version__}")
        exit()

    # Start GUI:
    app = App()
    app.run()


if __name__ == "__main__":
    run()



"""English translations of the program interface"""

MSG_DESC = "GUI wallpaper setter for Wayland and X11. It works as a frontend for feh, swaybg, wallutils, and swww."
MSG_INFO = "For more information, visit:\nhttps://github.com/anufrievroman/waypaper"

MSG_ARG_HELP = "print version of the program"
MSG_ARG_FILL = "specify how to fill the screen with chosen image"
MSG_ARG_REST = "restore last wallpaper"
MSG_ARG_BACK = "specify which backend to use to set wallpaper"

MSG_PATH = "Selected image path:"
MSG_SELECT = "Select"
MSG_REFRESH = "Refresh"
MSG_EXIT = "Exit"
MSG_SUBFOLDERS = "Subfolders"
MSG_CHANGEFOLDER = "Change wallpaper folder"
MSG_CACHING = "Caching wallpapers..."
MSG_SETWITH = "Wallpaper was set with"

MSG_HELP = "Waypaper's hotkeys:\n\nhjkl - Navigation (←↓↑→)\n"
MSG_HELP += "g - Scroll to top\nG - Scroll to bottom\n"
MSG_HELP += "s - Include/exclude images in subfolders\n? - Help\nq - Exit\n\n"
MSG_HELP += MSG_INFO

ERR_CACHE = "Error deleting cache"
ERR_BACKEND = "Looks like none of the wallpaper backends is installed in the system.\n"
ERR_BACKEND += "Use your package manager to install at least one of these backends:\n\n"
ERR_BACKEND += "- swaybg (for Wayland)\n- swww (for Wayland)\n"
ERR_BACKEND += "- feh (for Xorg)\n- wallutils (for Xorg & Wayland)\n\n"
ERR_BACKEND += MSG_INFO
ERR_WALL = "Error changing wallpaper: "
ERR_NOTSUP = "The backend is not supported:"



"""Module that parses user arguments and returns them in args object"""

import argparse

from waypaper.options import FILL_OPTIONS, BACKEND_OPTIONS
from waypaper.translation_en import *


parser = argparse.ArgumentParser(prog = "waypaper", description = MSG_DESC, epilog = MSG_INFO)
parser.add_argument("-v", "--version", help=MSG_ARG_HELP, action="store_true")
parser.add_argument("--restore", help=MSG_ARG_REST, action="store_true")
parser.add_argument("--fill", help=MSG_ARG_FILL, choices=FILL_OPTIONS)
parser.add_argument("--backend", help=MSG_ARG_BACK, choices=BACKEND_OPTIONS)
args = parser.parse_args()



from pathlib import Path
import re
import setuptools

setup_dir = Path(__file__).resolve().parent

version = re.search( r'__version__ = "(.*)"', Path(setup_dir, 'waypaper/__main__.py').open().read())
if version is None:
    raise SystemExit("Could not determine version to use")
version = version.group(1)
setuptools.setup(
    name='waypaper',
    author='Roman Anufriev',
    author_email='anufriev.roman@protonmail.com',
    url='https://github.com/anufrievroman/waypaper',
    description='GUI wallpaper setter for Wayland',
    long_description=Path(setup_dir, 'README.md').open().read(),
    long_description_content_type='text/markdown',
    license='GPL',
    entry_points={
        "console_scripts": [
            "waypaper = waypaper.__main__:run"
        ]
    },
    install_requires=["PyGObject"],
    version=version,
    python_requires='>3.10',
    classifiers=[
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Environment :: Console",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Utilities",
    ],
    packages=["waypaper"],
    include_package_data=True,
)
